@@ -28,11 +28,11 @@
 #' Use these functions to return a specific property of an antibiotic from the [antibiotics] data set. All input values will be evaluated internally with [as.ab()].
 #' @inheritSection lifecycle Stable Lifecycle
 #' @param x any (vector of) text that can be coerced to a valid antibiotic code with [as.ab()]
-#' @param tolower logical to indicate whether the first character of every output should be transformed to a lower case character. This will lead to e.g. "polymyxin B" and not "polymyxin b".
+#' @param tolower a [logical] to indicate whether the first [character] of every output should be transformed to a lower case [character]. This will lead to e.g. "polymyxin B" and not "polymyxin b".
 #' @param property one of the column names of one of the [antibiotics] data set
 #' @param language language of the returned text, defaults to system language (see [get_locale()]) and can also be set with `getOption("AMR_locale")`. Use `language = NULL` or `language = ""` to prevent translation.
 #' @param administration way of administration, either `"oral"` or `"iv"`
-#' @param units a logical to indicate whether the units instead of the DDDs itself must be returned, see *Examples*
+#' @param units a [logical] to indicate whether the units instead of the DDDs itself must be returned, see *Examples*
 #' @param open browse the URL using [utils::browseURL()]
 #' @param ... other arguments passed on to [as.ab()]
 #' @details All output [will be translated][translate] where possible.
@@ -93,7 +93,7 @@ ab_name <- function(x, language = get_locale(), tolower = FALSE, ...) {
   meet_criteria(language, has_length = 1, is_in = c(LANGUAGES_SUPPORTED, ""), allow_NULL = TRUE, allow_NA = TRUE)
   meet_criteria(tolower, allow_class = "logical", has_length = 1)
   
-  x <- translate_AMR(ab_validate(x = x, property = "name", ...), language = language)
+  x <- translate_AMR(ab_validate(x = x, property = "name", ...), language = language, only_affect_ab_names = TRUE)
   if (tolower == TRUE) {
     # use perl to only transform the first character
     # as we want "polymyxin B", not "polymyxin b"
@@ -142,7 +142,7 @@ ab_tradenames <- function(x, ...) {
 ab_group <- function(x, language = get_locale(), ...) {
   meet_criteria(x, allow_NA = TRUE)
   meet_criteria(language, has_length = 1, is_in = c(LANGUAGES_SUPPORTED, ""), allow_NULL = TRUE, allow_NA = TRUE)
-  translate_AMR(ab_validate(x = x, property = "group", ...), language = language)
+  translate_AMR(ab_validate(x = x, property = "group", ...), language = language, only_affect_ab_names = TRUE)
 }
 
 #' @rdname ab_property
@@ -150,7 +150,7 @@ ab_group <- function(x, language = get_locale(), ...) {
 ab_atc_group1 <- function(x, language = get_locale(), ...) {
   meet_criteria(x, allow_NA = TRUE)
   meet_criteria(language, has_length = 1, is_in = c(LANGUAGES_SUPPORTED, ""), allow_NULL = TRUE, allow_NA = TRUE)
-  translate_AMR(ab_validate(x = x, property = "atc_group1", ...), language = language)
+  translate_AMR(ab_validate(x = x, property = "atc_group1", ...), language = language, only_affect_ab_names = TRUE)
 }
 
 #' @rdname ab_property
@@ -158,7 +158,7 @@ ab_atc_group1 <- function(x, language = get_locale(), ...) {
 ab_atc_group2 <- function(x, language = get_locale(), ...) {
   meet_criteria(x, allow_NA = TRUE)
   meet_criteria(language, has_length = 1, is_in = c(LANGUAGES_SUPPORTED, ""), allow_NULL = TRUE, allow_NA = TRUE)
-  translate_AMR(ab_validate(x = x, property = "atc_group2", ...), language = language)
+  translate_AMR(ab_validate(x = x, property = "atc_group2", ...), language = language, only_affect_ab_names = TRUE)
 }
 
 #' @rdname ab_property
