@@ -60,12 +60,14 @@ CATALOGUE_OF_LIFE <- list(
 globalVariables(c(".rowid",
                   "ab",
                   "ab_txt",
+                  "affect_ab_name",
                   "affect_mo_name",
                   "angle",
                   "antibiotic",
                   "antibiotics",
                   "atc_group1",
                   "atc_group2",
+                  "base_ab",
                   "code",
                   "cols",
                   "count",
