@@ -23,30 +23,29 @@
 # how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
 # ==================================================================== #
 
-#' Pattern Matching with Keyboard Shortcut
+#' Vectorised Pattern Matching with Keyboard Shortcut
 #'
 #' Convenient wrapper around [grepl()] to match a pattern: `x %like% pattern`. It always returns a [`logical`] vector and is always case-insensitive (use `x %like_case% pattern` for case-sensitive matching). Also, `pattern` can be as long as `x` to compare items of each index in both vectors, or they both can have the same length to iterate over all cases.
 #' @inheritSection lifecycle Stable Lifecycle
-#' @param x a character vector where matches are sought, or an object which can be coerced by [as.character()] to a character vector.
-#' @param pattern a character string containing a regular expression (or [character] string for `fixed = TRUE`) to be matched in the given character vector. Coerced by [as.character()] to a character string if possible.  If a [character] vector of length 2 or more is supplied, the first element is used with a warning.
+#' @param x a [character] vector where matches are sought, or an object which can be coerced by [as.character()] to a [character] vector.
+#' @param pattern a [character] vector containing regular expressions (or a [character] string for `fixed = TRUE`) to be matched in the given [character] vector. Coerced by [as.character()] to a [character] string if possible.
 #' @param ignore.case if `FALSE`, the pattern matching is *case sensitive* and if `TRUE`, case is ignored during matching.
-#' @return A [`logical`] vector
+#' @return A [logical] vector
 #' @name like
 #' @rdname like
 #' @export
 #' @details
-#' The `%like%` function:
-#' * Is case-insensitive (use `%like_case%` for case-sensitive matching)
-#' * Supports multiple patterns
-#' * Checks if `pattern` is a regular expression and sets `fixed = TRUE` if not, to greatly improve speed
-#' * Always uses compatibility with Perl
+#' These [like()] and `%like%`/`%unlike%` functions:
+#' * Are case-insensitive (use `%like_case%`/`%unlike_case%` for case-sensitive matching)
+#' * Support multiple patterns
+#' * Check if `pattern` is a valid regular expression and sets `fixed = TRUE` if not, to greatly improve speed (vectorised over `pattern`)
+#' * Always use compatibility with Perl unless `fixed = TRUE`, to greatly improve speed
 #' 
-#' Using RStudio? The text `%like%` can also be directly inserted in your code from the Addins menu and can have its own Keyboard Shortcut like `Ctrl+Shift+L` or `Cmd+Shift+L` (see `Tools` > `Modify Keyboard Shortcuts...`).
-#' @source Idea from the [`like` function from the `data.table` package](https://github.com/Rdatatable/data.table/blob/master/R/like.R)
+#' Using RStudio? The `%like%`/`%unlike%` functions can also be directly inserted in your code from the Addins menu and can have its own keyboard shortcut like `Shift+Ctrl+L` or `Shift+Cmd+L` (see menu `Tools` > `Modify Keyboard Shortcuts...`). If you keep pressing your shortcut, the inserted text will be iterated over `%like%` -> `%unlike%` -> `%like_case%` -> `%unlike_case%`.
+#' @source Idea from the [`like` function from the `data.table` package](https://github.com/Rdatatable/data.table/blob/ec1259af1bf13fc0c96a1d3f9e84d55d8106a9a4/R/like.R), although altered as explained in *Details*.
 #' @seealso [grepl()]
 #' @inheritSection AMR Read more on Our Website!
 #' @examples
-#' # simple test
 #' a <- "This is a test"
 #' b <- "TEST"
 #' a %like% b
@@ -59,16 +58,23 @@
 #' b <- c(     "case",           "diff",      "yet")
 #' a %like% b
 #' #> TRUE TRUE TRUE
+#' a %unlike% b
+#' #> FALSE FALSE FALSE
+#' 
 #' a[1] %like% b
 #' #> TRUE FALSE FALSE
 #' a %like% b[1]
 #' #> TRUE FALSE FALSE
 #' 
 #' # get isolates whose name start with 'Ent' or 'ent'
+#' example_isolates[which(mo_name(example_isolates$mo) %like% "^ent"), ]
 #' \donttest{
+#' # faster way, only works in R 3.2 and later:
+#' example_isolates[which(mo_name() %like% "^ent"), ]
+#' 
 #' if (require("dplyr")) {
 #'   example_isolates %>%
-#'     filter(mo_name(mo) %like% "^ent")
+#'     filter(mo_name() %like% "^ent")
 #' }
 #' }
 like <- function(x, pattern, ignore.case = TRUE) {
@@ -79,9 +85,10 @@ like <- function(x, pattern, ignore.case = TRUE) {
   if (all(is.na(x))) {
     return(rep(FALSE, length(x)))
   }
-  
-  # set to fixed if no regex found
-  fixed <- !any(is_possibly_regex(pattern))
+
+  # set to fixed if no valid regex (vectorised)
+  fixed <- !is_valid_regex(pattern)
+
   if (ignore.case == TRUE) {
     # set here, otherwise if fixed = TRUE, this warning will be thrown: argument `ignore.case = TRUE` will be ignored
     x <- tolower(x)
@@ -91,21 +98,26 @@ like <- function(x, pattern, ignore.case = TRUE) {
   if (is.factor(x)) {
     x <- as.character(x)
   }
-  
+
   if (length(pattern) == 1) {
     grepl(pattern, x, ignore.case = FALSE, fixed = fixed, perl = !fixed)
   } else {
     if (length(x) == 1) {
       x <- rep(x, length(pattern))
     } else if (length(pattern) != length(x)) {
-      stop_("arguments `x` and `pattern` must be of same length, or either one must be 1")
+      stop_("arguments `x` and `pattern` must be of same length, or either one must be 1 ",
+            "(`x` has length ", length(x), " and `pattern` has length ", length(pattern), ")")
     }
     unlist(
-      Map(f = grepl,
-          pattern,
-          x,
-          MoreArgs = list(ignore.case = FALSE, fixed = fixed, perl = !fixed)),
-      use.names = FALSE)
+      mapply(FUN = grepl,
+             x = x,
+             pattern = pattern,
+             fixed = fixed,
+             perl = !fixed,
+             MoreArgs = list(ignore.case = FALSE),
+             SIMPLIFY = FALSE,
+             USE.NAMES = FALSE)
+    )
   }
 }
 
@@ -117,6 +129,14 @@ like <- function(x, pattern, ignore.case = TRUE) {
   like(x, pattern, ignore.case = TRUE)
 }
 
+#' @rdname like
+#' @export
+"%unlike%" <- function(x, pattern) {
+  meet_criteria(x, allow_NA = TRUE)
+  meet_criteria(pattern, allow_NA = FALSE)
+  !like(x, pattern, ignore.case = TRUE)
+}
+
 #' @rdname like
 #' @export
 "%like_case%" <- function(x, pattern) {
@@ -124,3 +144,11 @@ like <- function(x, pattern, ignore.case = TRUE) {
   meet_criteria(pattern, allow_NA = FALSE)
   like(x, pattern, ignore.case = FALSE)
 }
+
+#' @rdname like
+#' @export
+"%unlike_case%" <- function(x, pattern) {
+  meet_criteria(x, allow_NA = TRUE)
+  meet_criteria(pattern, allow_NA = FALSE)
+  !like(x, pattern, ignore.case = FALSE)
+}
