@@ -27,12 +27,12 @@
 #' 
 #' Performs a principal component analysis (PCA) based on a data set with automatic determination for afterwards plotting the groups and labels, and automatic filtering on only suitable (i.e. non-empty and numeric) variables.
 #' @inheritSection lifecycle Stable Lifecycle
-#' @param x a [data.frame] containing numeric columns
+#' @param x a [data.frame] containing [numeric] columns
 #' @param ... columns of `x` to be selected for PCA, can be unquoted since it supports quasiquotation.
 #' @inheritParams stats::prcomp
 #' @details The [pca()] function takes a [data.frame] as input and performs the actual PCA with the \R function [prcomp()].
 #' 
-#' The result of the [pca()] function is a [prcomp] object, with an additional attribute `non_numeric_cols` which is a vector with the column names of all columns that do not contain numeric values. These are probably the groups and labels, and will be used by [ggplot_pca()].
+#' The result of the [pca()] function is a [prcomp] object, with an additional attribute `non_numeric_cols` which is a vector with the column names of all columns that do not contain [numeric] values. These are probably the groups and labels, and will be used by [ggplot_pca()].
 #' @return An object of classes [pca] and [prcomp]
 #' @importFrom stats prcomp
 #' @export
@@ -42,7 +42,6 @@
 #' # See ?example_isolates.
 #'
 #' \donttest{
-#' 
 #' if (require("dplyr")) {
 #'   # calculate the resistance per group first 
 #'   resistance_data <- example_isolates %>% 
@@ -99,7 +98,7 @@ pca <- function(x,
     
     x <- as.data.frame(new_list, stringsAsFactors = FALSE)
     if (any(vapply(FUN.VALUE = logical(1), x, function(y) !is.numeric(y)))) {
-      warning_("Be sure to first calculate the resistance (or susceptibility) of variables with antimicrobial test results, since PCA works with numeric variables only. See Examples in ?pca.", call = FALSE)
+      warning_("Be sure to first calculate the resistance (or susceptibility) of variables with antimicrobial test results, since PCA works with [numeric] variables only. See Examples in ?pca.", call = FALSE)
     }
     
     # set column names
@@ -120,7 +119,7 @@ pca <- function(x,
   message_("Columns selected for PCA: ", vector_and(font_bold(colnames(pca_data), collapse = NULL), quotes = TRUE),
            ". Total observations available: ", nrow(pca_data), ".")
   
-  if (as.double(R.Version()$major) + (as.double(R.Version()$minor) / 10) < 3.4) {
+  if (getRversion() < "3.4.0") {
     # stats::prcomp prior to 3.4.0 does not have the 'rank.' argument
     pca_model <- prcomp(pca_data, retx = retx, center = center, scale. = scale., tol = tol)
   } else {
