@@ -123,7 +123,11 @@ coerce_language_setting <- function(lang) {
 }
 
 # translate strings based on inst/translations.tsv
-translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE, affect_mo_name = FALSE) {
+translate_AMR <- function(from,
+                          language = get_locale(), 
+                          only_unknown = FALSE,
+                          only_affect_ab_names = FALSE,
+                          only_affect_mo_names = FALSE) {
   
   if (is.null(language)) {
     return(from)
@@ -144,12 +148,20 @@ translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE, a
   
   # only keep lines where translation is available for this language
   df_trans <- df_trans[which(!is.na(df_trans[, language, drop = TRUE])), , drop = FALSE]
+  # and where the original string is not equal to the string in the target language
+  df_trans <- df_trans[which(df_trans[, "pattern", drop = TRUE] != df_trans[, language, drop = TRUE]), , drop = FALSE]
   if (only_unknown == TRUE) {
     df_trans <- subset(df_trans, pattern %like% "unknown")
   }
-  if (affect_mo_name == TRUE) {
+  if (only_affect_ab_names == TRUE) {
+    df_trans <- subset(df_trans, affect_ab_name == TRUE)
+  }
+  if (only_affect_mo_names == TRUE) {
     df_trans <- subset(df_trans, affect_mo_name == TRUE)
   }
+  if (NROW(df_trans) == 0) {
+    return(from)
+  }
   
   # default: case sensitive if value if 'case_sensitive' is missing:
   df_trans$case_sensitive[is.na(df_trans$case_sensitive)] <- TRUE
@@ -157,11 +169,13 @@ translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE, a
   df_trans$regular_expr[is.na(df_trans$regular_expr)] <- FALSE
   
   # check if text to look for is in one of the patterns
-  any_form_in_patterns <- tryCatch(any(from_unique %like% paste0("(", paste(df_trans$pattern, collapse = "|"), ")")),
-                                   error = function(e) {
-                                     warning_("Translation not possible. Please open an issue on GitHub (https://github.com/msberends/AMR/issues).", call = FALSE)
-                                     return(FALSE)
-                                   })
+  any_form_in_patterns <- tryCatch(
+    any(from_unique %like% paste0("(", paste(gsub(" +\\(.*", "", df_trans$pattern), collapse = "|"), ")")),
+    error = function(e) {
+      warning_("Translation not possible. Please open an issue on GitHub (https://github.com/msberends/AMR/issues).", call = FALSE)
+      return(FALSE)
+    })
+  
   if (NROW(df_trans) == 0 | !any_form_in_patterns) {
     return(from)
   }
@@ -170,7 +184,7 @@ translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE, a
          function(i) from_unique_translated <<- gsub(pattern = df_trans$pattern[i],
                                                      replacement = df_trans[i, language, drop = TRUE],
                                                      x = from_unique_translated,
-                                                     ignore.case = !df_trans$case_sensitive[i], 
+                                                     ignore.case = !df_trans$case_sensitive[i] & df_trans$regular_expr[i], 
                                                      fixed = !df_trans$regular_expr[i],
                                                      perl = df_trans$regular_expr[i]))
   
