@@ -5,6 +5,17 @@ knitr::opts_chunk$set(
 )
 library(AMR)
 
+## -----------------------------------------------------------------------------
+custom <- custom_mdro_guideline(CIP == "R" & age > 60 ~ "Elderly Type A",
+                                ERY == "R" & age > 60 ~ "Elderly Type B")
+
+## -----------------------------------------------------------------------------
+custom
+
+## -----------------------------------------------------------------------------
+x <- mdro(example_isolates, guideline = custom)
+table(x)
+
 ## ---- message = FALSE---------------------------------------------------------
 library(dplyr)   # to support pipes: %>%
 library(cleaner) # to create frequency tables
@@ -20,31 +31,24 @@ example_isolates %>%
   freq() # show frequency table of the result
 
 ## -----------------------------------------------------------------------------
-# a helper function to get a random vector with values S, I and R
-# with the probabilities 50% - 10% - 40%
-sample_rsi <- function() {
-  sample(c("S", "I", "R"),
-         size = 5000,
-         prob = c(0.5, 0.1, 0.4),
-         replace = TRUE)
-}
-
-my_TB_data <- data.frame(rifampicin = sample_rsi(),
-                         isoniazid = sample_rsi(),
-                         gatifloxacin = sample_rsi(),
-                         ethambutol = sample_rsi(),
-                         pyrazinamide = sample_rsi(),
-                         moxifloxacin = sample_rsi(),
-                         kanamycin = sample_rsi())
+# random_rsi() is a helper function to generate
+# a random vector with values S, I and R
+my_TB_data <- data.frame(rifampicin = random_rsi(5000),
+                         isoniazid = random_rsi(5000),
+                         gatifloxacin = random_rsi(5000),
+                         ethambutol = random_rsi(5000),
+                         pyrazinamide = random_rsi(5000),
+                         moxifloxacin = random_rsi(5000),
+                         kanamycin = random_rsi(5000))
 
 ## ---- eval = FALSE------------------------------------------------------------
-#  my_TB_data <- data.frame(RIF = sample_rsi(),
-#                           INH = sample_rsi(),
-#                           GAT = sample_rsi(),
-#                           ETH = sample_rsi(),
-#                           PZA = sample_rsi(),
-#                           MFX = sample_rsi(),
-#                           KAN = sample_rsi())
+#  my_TB_data <- data.frame(RIF = random_rsi(5000),
+#                           INH = random_rsi(5000),
+#                           GAT = random_rsi(5000),
+#                           ETH = random_rsi(5000),
+#                           PZA = random_rsi(5000),
+#                           MFX = random_rsi(5000),
+#                           KAN = random_rsi(5000))
 
 ## -----------------------------------------------------------------------------
 head(my_TB_data)
